// Copyright (c) 2017, Agilord. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:async';

import 'package:ecb_fx/ecb_fx.dart';
import 'package:http_client/console.dart' as http;

final portfolio = <String, num>{
  'USD': 200000 + 60000 + 31000,
  'EUR': 50000,
  'HUF': (44 + 12 + 15) * 1000000,
};

final targetPercents = <String, double>{
  'USD': 31.0,
  'EUR': 31.0,
  'HUF': 31.0,
  'GBP': 01.0,
  'CAD': 01.0,
  'CHF': 01.0,
  'CNY': 01.0,
  'JPY': 01.0,
  'INR': 01.0,
  'AUD': 01.0,
};

Future main() async {
  http.Client httpClient = new http.ConsoleClient();
  EcbFxClient ecbFxClient = new EcbFxClient(httpClient);

  final rates = await ecbFxClient.getCurrent();
  await httpClient.close();

  final targetPctTotal = targetPercents.values.fold(0, (a, b) => a + b);

  final total = portfolio.keys
      .map((key) => portfolio[key] / (key == 'EUR' ? 1 : rates.getDouble(key)))
      .fold<double>(0, (a, b) => a + b);

  print('${total.toStringAsFixed(2)} EUR total');
  for (String key in portfolio.keys) {
    final rate = (key == 'EUR' ? 1 : rates.getDouble(key));
    final pct = 100.0 * portfolio[key] / rate / total;
    print('$key: ${pct.toStringAsFixed(2)}');
  }

  final targetDiffs = <String, double>{};
  final targetDiffsInEur = <String, double>{};
  for (String key in targetPercents.keys) {
    final rate = (key == 'EUR' ? 1 : rates.getDouble(key));
    final targetAmount = total * targetPercents[key] / targetPctTotal;
    final diffInEur = targetAmount - ((portfolio[key] ?? 0.0) / rate);
    targetDiffsInEur[key] = diffInEur;
    targetDiffs[key] = diffInEur * rate;
  }

  print(targetDiffs);
  print(targetDiffsInEur);
}
